@@ -1,4 +1,4 @@
-#' data.table::fcase() with vectorized default
+#' `data.table::fcase()` with vectorized default
 #'
 #' @description
 #' This function allows you to use multiple if/else statements in one call.
@@ -8,6 +8,8 @@
 #'
 #' @param ... Sequence of condition/value designations
 #' @param default Default value. Set to NA by default.
+#' @param ptype Optional ptype to specify the output type.
+#' @param size Optional size to specify the output size.
 #'
 #' @export
 #'
@@ -16,9 +18,9 @@
 #'
 #' df %>%
 #'   mutate(case_x = case(x < 5, 1,
-#'                          x < 7, 2,
-#'                          default = 3))
-case <- function(..., default = NA) {
+#'                        x < 7, 2,
+#'                        default = 3))
+case <- function(..., default = NA, ptype = NULL, size = NULL) {
   dots <- list2(...)
   dots_length <- length(dots)
 
@@ -29,23 +31,22 @@ case <- function(..., default = NA) {
   conditions_locs <- as.logical(seq_len(dots_length) %% 2)
 
   conditions <- dots[conditions_locs]
-  size <- vec_size_common(!!!conditions)
+  size <- vec_size_common(!!!conditions, .size = size)
   conditions <- vec_recycle_common(!!!conditions, .size = size)
 
   values <- dots[!conditions_locs]
-  ptype <- vec_ptype_common(!!!values)
+  ptype <- vec_ptype_common(!!!values, .ptype = ptype)
   values <- vec_cast_common(!!!values, .to = ptype)
 
   pairs <- vec_interleave(conditions, values)
 
+  .default <- vec_cast(default, ptype)
+
   if (length(default) == 1) {
-    default <- vec_cast(default, ptype)
-    out <- exec(fcase, !!!pairs, default = default)
+    out <- exec(fcase, !!!pairs, default = .default)
   } else {
     .default_condition <- vec_recycle(TRUE, size)
-    .default_value <- vec_cast(default, ptype)
-
-    out <- exec(fcase, !!!pairs, .default_condition, .default_value)
+    out <- exec(fcase, !!!pairs, .default_condition, .default)
   }
 
   out
