@@ -12,20 +12,20 @@
 #' @examples
 #' # Use a single value to replace all missing values
 #' x <- c(1:3, NA, NA)
-#' coalesce.(x, 0)
+#' coalesce(x, 0)
 #'
 #' # Or match together a complete vector from missing pieces
 #' y <- c(1, 2, NA, NA, 5)
 #' z <- c(NA, NA, 3, 4, 5)
-#' coalesce.(y, z)
+#' coalesce(y, z)
 #'
 #' # Supply lists with dynamic dots
 #' vecs <- list(
 #'   c(1, 2, NA, NA, 5),
 #'   c(NA, NA, 3, 4, 5)
 #' )
-#' coalesce.(!!!vecs)
-coalesce. <- function(..., .ptype = NULL, .size = NULL) {
+#' coalesce(!!!vecs)
+coalesce <- function(..., .ptype = NULL, .size = NULL) {
   args <- list2(...)
   args <- vec_cast_common(!!!args, .to = .ptype)
 
@@ -37,3 +37,8 @@ coalesce. <- function(..., .ptype = NULL, .size = NULL) {
 
   out
 }
+
+#' @export
+#' @keywords internal
+#' @inherit coalesce
+coalesce. <- coalesce
