@@ -14,10 +14,17 @@
 #' df <- data.table(x = 1:2, y = 1:2, z = 3:4)
 #'
 #' df %>%
-#'   complete.(x, y)
+#'   complete(x, y)
 #'
 #' df %>%
-#'   complete.(x, y, fill = list(z = 10))
+#'   complete(x, y, fill = list(z = 10))
+complete <- function(.df, ..., fill = list(), .by = NULL) {
+  complete.(.df, ..., fill = fill, .by = {{ .by }})
+}
+
+#' @export
+#' @keywords internal
+#' @inherit complete
 complete. <- function(.df, ..., fill = list(), .by = NULL) {
   UseMethod("complete.")
 }
@@ -25,21 +32,32 @@ complete. <- function(.df, ..., fill = list(), .by = NULL) {
 #' @export
 complete..tidytable <- function(.df, ..., fill = list(), .by = NULL) {
   dots <- enquos(...)
-  dots <- dots[!map_lgl.(dots, quo_is_null)]
+  dots <- dots[!map_lgl(dots, quo_is_null)]
   if (length(dots) == 0) return(.df)
 
-  full_df <- expand.(.df, !!!dots, .by = {{ .by }})
+  full_df <- expand(.df, !!!dots, .by = {{ .by }})
 
   if (is_empty(full_df)) return(.df)
 
-  full_df <- full_join.(full_df, .df, by = names(full_df))
-  full_df <- replace_na.(full_df, replace = fill)
+  full_df <- full_join(full_df, .df, by = names(full_df))
+  full_df <- replace_na(full_df, replace = fill)
 
   full_df
 }
 
+#' @export
+complete..grouped_tt <- function(.df, ..., fill = list(), .by = NULL) {
+  check_by({{ .by }})
+  .by <- group_vars(.df)
+  out <- ungroup(.df)
+  out <- complete(.df, ..., fill = fill, .by = all_of(.by))
+  group_by(out, all_of(.by))
+}
+
 #' @export
 complete..data.frame <- function(.df, ..., fill = list(), .by = NULL) {
   .df <- as_tidytable(.df)
-  complete.(.df, ..., fill = fill, .by = {{ .by }})
+  complete(.df, ..., fill = fill, .by = {{ .by }})
 }
+
+
