@@ -1,6 +1,10 @@
 #' Extract a character column into multiple columns using regex
 #'
 #' @description
+#' _Superseded_
+#'
+#' `extract()` has been superseded by `separate_wider_regex()`.
+#'
 #' Given a regular expression with capturing groups, `extract()` turns each group
 #' into a new column. If the groups don't match, or the input is `NA`, the output
 #' will be `NA`. When you pass same name in the `into` argument it will merge
@@ -49,7 +53,7 @@ extract. <- function(.df, col, into, regex = "([[:alnum:]]+)",
 extract..tidytable <- function(.df, col, into, regex = "([[:alnum:]]+)",
                                 remove = TRUE, convert = FALSE, ...) {
 
-  col <- tidyselect_locs(.df, {{ col }})
+  col <- tidyselect_names(.df, {{ col }})
 
   groups <- str_extract_groups(.df[[col]], regex, convert = convert)
 
@@ -59,12 +63,12 @@ extract..tidytable <- function(.df, col, into, regex = "([[:alnum:]]+)",
     )
   }
 
-  keep_group <- !is.na(into)
-  groups <- groups[keep_group]
-  into <- into[keep_group]
+  keep <- vec_detect_complete(into)
+  into <- into[keep]
+  groups <- groups[keep]
 
   if (vec_duplicate_any(into)) {
-    groups <- lapply(split(groups, into), pmap_chr., paste0)
+    groups <- lapply(split(groups, into), pmap_chr, paste0)
     into <- names(groups)
   }
 
@@ -72,15 +76,17 @@ extract..tidytable <- function(.df, col, into, regex = "([[:alnum:]]+)",
     groups <- lapply(groups, type.convert, as.is = TRUE)
   }
 
-  .df <- dt_j(.df, (into) := ..groups)
+  out <- dt_j(.df, (into) := ..groups)
 
-  if (remove) {
-    .df <- dt_j(.df, (col) := NULL)
+  if (remove && col %notin% into) {
+    out <- dt_j(out, (col) := NULL)
   }
 
-  .df
+  out
 }
 
+globalVariables("..groups")
+
 #' @export
 extract..data.frame <- function(.df, col, into, regex = "([[:alnum:]]+)",
                                 remove = TRUE, convert = FALSE, ...) {
@@ -106,5 +112,3 @@ str_extract_groups <- function(string, pattern, convert = FALSE){
     function(.x) substr(string, start[, .x], end[, .x])
   )
 }
-
-globalVariables("..groups")
