@@ -4,7 +4,7 @@
 #' Convert values to `NA`.
 #'
 #' @param x A vector
-#' @param y Value(s) to replace with `NA`
+#' @param y Value to replace with `NA`
 #'
 #' @export
 #'
@@ -12,11 +12,9 @@
 #' vec <- 1:3
 #' na_if(vec, 3)
 na_if <- function(x, y) {
-  if (length(y) == 1) {
-    vec_assign(x, x == y, NA)
-  } else {
-    vec_assign(x, x %in% y, NA)
-  }
+  size <- vec_size(x)
+  y <- vec_recycle(y, size)
+  vec_assign(x, x == y, NA)
 }
 
 #' @export
