@@ -1,13 +1,18 @@
 #' Separate a character column into multiple columns
 #'
 #' @description
+#' _Superseded_
+#'
+#' `separate()` has been superseded by `separate_wider_delim()`.
+#'
 #' Separates a single column into multiple columns using a user supplied separator or regex.
 #'
 #' If a separator is not supplied one will be automatically detected.
 #'
-#' Note: Using automatic detection or regex will be slower than simple separators such as "," or ".".
+#' Note: Using automatic detection or regex will be slower than simple separators
+#' such as "," or ".".
 #'
-#' @param .df A data.frame or data.table
+#' @param .df A data frame
 #' @param col The column to split into multiple columns
 #' @param into New column names to split into. A character vector.
 #' Use `NA` to omit the variable in the output.
@@ -66,30 +71,46 @@ separate..tidytable <- function(.df, col, into,
     fixed <- FALSE
   }
 
-  col <- enquo(col)
+  col <- tidyselect_names(.df, {{ col }})
 
-  col <- tidyselect_syms(.df, !!col)[[1]]
+  t_str_split <- tstrsplit(.df[[col]],
+                           split = sep, fixed = fixed,
+                           type.convert = convert)
 
-  not_na_into <- vec_detect_complete(into)
+  into_length <- length(into)
+  split_length <- length(t_str_split)
 
-  keep <- seq_along(into)[not_na_into]
-  into <- into[not_na_into]
-
-  t_str_split <- call2(
-    "tstrsplit", col, split = sep, fixed = fixed,
-    keep = keep, type.convert = convert,
-    .ns = "data.table"
-  )
-
-  .df <- dt_j(.df, (into) := !!t_str_split)
-
-  if (remove) {
-    .df <- dt_j(.df, !!col := NULL)
+  if (into_length > split_length) {
+    extra <- into[(split_length + 1):into_length]
+    into <- into[1:split_length]
+  } else if (into_length < split_length) {
+    t_str_split <- t_str_split[1:into_length]
+    extra <- character()
+  } else {
+    extra <- character()
   }
 
-  .df
+  is_complete <- vec_detect_complete(into)
+
+  into <- into[is_complete]
+
+  t_str_split <- t_str_split[is_complete]
+
+  out <- dt_j(.df, (into) := ..t_str_split)
+
+  if (length(extra) > 0) {
+    out <- dt_j(out, (extra) := NA_character_)
+  }
+
+  if (remove && col %notin% into) {
+    out <- dt_j(out, (col) := NULL)
+  }
+
+  out
 }
 
+globalVariables("..t_str_split")
+
 #' @export
 separate..data.frame <- function(.df, col, into,
                                  sep = "[^[:alnum:]]+",
