@@ -19,23 +19,35 @@
 #' )
 #'
 #' # Automatically creates names
-#' df %>% unnest_wider.(y)
+#' df %>% unnest_wider(y)
 #'
 #' # But you can provide names_sep for increased naming control
-#' df %>% unnest_wider.(y, names_sep = "_")
+#' df %>% unnest_wider(y, names_sep = "_")
+unnest_wider <- function(.df, col, names_sep = NULL,
+                         simplify = NULL, names_repair = "check_unique",
+                         ptype = NULL, transform = NULL) {
+  unnest_wider.(
+    .df, col = {{ col }}, names_sep = names_sep, simplify = simplify,
+    names_repair = names_repair, ptype = ptype, transform = transform
+  )
+}
+
+#' @export
+#' @keywords internal
+#' @inherit unnest_wider
 unnest_wider. <- function(.df, col, names_sep = NULL,
                           simplify = NULL, names_repair = "check_unique",
-                          ptype = list(), transform = list()) {
+                          ptype = NULL, transform = NULL) {
   UseMethod("unnest_wider.")
 }
 
 #' @export
 unnest_wider..tidytable <- function(.df, col, names_sep = NULL,
                                     simplify = NULL, names_repair = "check_unique",
-                                    ptype = list(), transform = list()) {
+                                    ptype = NULL, transform = NULL) {
   .col <- enquo(col)
 
-  .l <- pull.(.df, !!.col)
+  .l <- pull(.df, !!.col)
 
   if (!is_simple_vector(.l[[1]])) {
     abort("Only vectors are currently supported")
@@ -45,9 +57,11 @@ unnest_wider..tidytable <- function(.df, col, names_sep = NULL,
     abort("The simplify argument is not currently supported")
   }
 
-  .l <- map.(.l, ~ unnest_wider_tidytable(!!!.x))
+  .l <- map(.l, ~ unnest_wider_tidytable(!!!.x))
 
-  out <- bind_rows.(.l)
+  out <- bind_rows(.l)
+
+  new_names <- names(out)
 
   if (!is.null(names_sep)) {
     out_names <- names(out)
@@ -55,17 +69,16 @@ unnest_wider..tidytable <- function(.df, col, names_sep = NULL,
 
     out <- df_set_names(out, new_names, out_names)
   } else {
-    out <- df_name_repair(out, .name_repair = "universal")
+    out <- df_name_repair(out, "universal")
   }
 
   .df <- dt_j(.df, !!.col := NULL)
 
   if (ncol(.df) > 0) {
-    out <- bind_cols.(.df, out, .name_repair = names_repair)
+    out <- bind_cols(.df, out, .name_repair = names_repair)
   }
 
-  out <- change_types(out, names(out), ptype, "ptypes")
-  out <- change_types(out, names(out), transform, "transform")
+  out <- change_types(out, new_names, ptype, transform)
 
   out
 }
@@ -73,14 +86,15 @@ unnest_wider..tidytable <- function(.df, col, names_sep = NULL,
 #' @export
 unnest_wider..data.frame <- function(.df, col, names_sep = NULL,
                                      simplify = NULL, names_repair = "check_unique",
-                                     ptype = list(), transform = list()) {
+                                     ptype = NULL, transform = NULL) {
   .df <- as_tidytable(.df)
-  unnest_wider.(
+  unnest_wider(
     .df, col = {{ col }}, names_sep = names_sep, simplify = simplify,
     names_repair = names_repair, ptype = ptype, transform = transform
   )
 }
 
+
 unnest_wider_tidytable <- function(...) {
   dots <- list2(...)
   names(dots) <- names(dots) %||% seq_along(dots)
