@@ -2,7 +2,7 @@ test_that("can filter the data.table", {
   df <- data.table(x = 1:10)
 
   df <- df %>%
-    filter.(between.(x, 1, 4))
+    filter(between(x, 1, 4))
 
   expect_equal(df$x, 1:4)
 })
@@ -11,16 +11,16 @@ test_that("can filter a data.frame", {
   df <- data.frame(x = 1:10)
 
   df <- df %>%
-    filter.(between.(x, 1, 4))
+    filter(between(x, 1, 4))
 
   expect_equal(df$x, 1:4)
 })
 
-test_that("auto-translates between() to between.()", {
+test_that("works with dot", {
   df <- data.table(x = 1:10)
 
   df <- df %>%
-    filter.(between(x, 1, 4))
+    filter(between.(x, 1, 4))
 
   expect_equal(df$x, 1:4)
 })
