@@ -1,6 +1,15 @@
 # tests from tidyr regarding pivot_longer
 
 test_that("can pivot all cols (unspecified) to long", {
+  df <- data.table(x = 1:2, y = 3:4)
+  pivot_df <- pivot_longer(df)
+
+  expect_named(pivot_df, c("name", "value"))
+  expect_equal(pivot_df$name, c("x","x","y","y"))
+  expect_equal(pivot_df$value, 1:4)
+})
+
+test_that("pivot_longer. works", {
   df <- data.table(x = 1:2, y = 3:4)
   pivot_df <- pivot_longer.(df)
 
@@ -11,7 +20,7 @@ test_that("can pivot all cols (unspecified) to long", {
 
 test_that("can pivot all cols (unspecified) to long with data.frame", {
   df <- data.frame(x = 1:2, y = 3:4)
-  pivot_df <- pivot_longer.(df)
+  pivot_df <- pivot_longer(df)
 
   expect_named(pivot_df, c("name", "value"))
   expect_equal(pivot_df$name, c("x","x","y","y"))
@@ -20,7 +29,7 @@ test_that("can pivot all cols (unspecified) to long with data.frame", {
 
 test_that("doesn't convert character cols to factor", {
   df <- data.table(x = c("a", "b"), y = c("a", "b"))
-  pivot_df <- pivot_longer.(df)
+  pivot_df <- pivot_longer(df)
 
   expect_named(pivot_df, c("name", "value"))
   expect_equal(pivot_df$name, c("x","x","y","y"))
@@ -29,7 +38,7 @@ test_that("doesn't convert character cols to factor", {
 
 test_that("can pivot all cols (specified) to long", {
   df <- data.table(x = 1:2, y = 3:4)
-  pivot_df <- pivot_longer.(df, cols = c(x,y))
+  pivot_df <- pivot_longer(df, cols = c(x,y))
 
   expect_named(pivot_df, c("name", "value"))
   expect_equal(pivot_df$name, c("x","x","y","y"))
@@ -38,18 +47,36 @@ test_that("can pivot all cols (specified) to long", {
 
 test_that("can coerce names with names_transform", {
   df <- data.table("1"=10, "2"=20)
+  # transform in a list
   pivot_df <- df %>%
-    pivot_longer.(1:2, names_to = "int", names_transform = list(int = as.integer))
+    pivot_longer(1:2, names_to = "int", names_transform = list(int = as.integer))
 
   expect_named(pivot_df, c("int", "value"))
   expect_equal(pivot_df$int, c(1, 2))
+  expect_true(is.integer(pivot_df$int))
+  expect_equal(pivot_df$value, c(10, 20))
+
+  # Can pass single transform
+  pivot_df <- df %>%
+    pivot_longer(1:2, names_to = "int", names_transform = as.integer)
+
+  expect_named(pivot_df, c("int", "value"))
+  expect_equal(pivot_df$int, c(1, 2))
+  expect_true(is.integer(pivot_df$int))
   expect_equal(pivot_df$value, c(10, 20))
 })
 
 test_that("can coerce names with names_ptype", {
   df <- data.table("1"=10, "2"=20)
   pivot_df <- df %>%
-    pivot_longer.(1:2, names_to = "int", names_ptype = list(int = factor()))
+    pivot_longer(1:2, names_to = "int", names_ptype = list(int = factor()))
+
+  expect_named(pivot_df, c("int", "value"))
+  expect_equal(pivot_df$int, as.factor(c(1, 2)))
+  expect_equal(pivot_df$value, c(10, 20))
+
+  pivot_df <- df %>%
+    pivot_longer(1:2, names_to = "int", names_ptype = factor())
 
   expect_named(pivot_df, c("int", "value"))
   expect_equal(pivot_df$int, as.factor(c(1, 2)))
@@ -59,8 +86,17 @@ test_that("can coerce names with names_ptype", {
 test_that("can coerce values with values_transform", {
   df <- data.table(x = 1:2, y = 3:4)
   pivot_df <- df %>%
-    pivot_longer.(cols = c(x,y), values_transform = list(value = as.character)) %>%
-    arrange.(name, value)
+    pivot_longer(cols = c(x,y), values_transform = list(value = as.character)) %>%
+    arrange(name, value)
+
+  expect_named(pivot_df, c("name", "value"))
+  expect_equal(pivot_df$name, c("x","x","y","y"))
+  expect_equal(pivot_df$value, as.character(c(1,2,3,4)))
+
+  # Passing a single function
+  pivot_df <- df %>%
+    pivot_longer(cols = c(x,y), values_transform = as.character) %>%
+    arrange(name, value)
 
   expect_named(pivot_df, c("name", "value"))
   expect_equal(pivot_df$name, c("x","x","y","y"))
@@ -70,8 +106,12 @@ test_that("can coerce values with values_transform", {
 test_that("can coerce values with values_ptypes", {
   df <- data.table(x = 1:2, y = 3:4)
   pivot_df <- df %>%
-    pivot_longer.(cols = c(x,y), values_ptype = list(value = int())) %>%
-    arrange.(name, value)
+    pivot_longer(cols = c(x,y), values_ptype = list(value = int())) %>%
+    arrange(name, value)
+
+  pivot_df <- df %>%
+    pivot_longer(cols = c(x,y), values_ptype = int()) %>%
+    arrange(name, value)
 
   expect_named(pivot_df, c("name", "value"))
   expect_equal(pivot_df$name, c("x","x","y","y"))
@@ -80,8 +120,8 @@ test_that("can coerce values with values_ptypes", {
 
 test_that("preserves original keys", {
   df <- data.table(x = 1:2, y = 2, z = 1:2) %>%
-    mutate.(across.(everything(), as.double))
-  pivot_df <- pivot_longer.(df, cols = c(y, z))
+    mutate(across(everything(), as.double))
+  pivot_df <- pivot_longer(df, cols = c(y, z))
 
   expect_named(pivot_df, c("x", "name", "value"))
   expect_equal(pivot_df$x, c(1,2,1,2))
@@ -89,7 +129,7 @@ test_that("preserves original keys", {
 
 test_that("can drop missing values", {
   df <- data.table(x = c(1, NA), y = c(NA, 2))
-  pivot_df <- pivot_longer.(df, c(x,y), values_drop_na = TRUE)
+  pivot_df <- pivot_longer(df, c(x,y), values_drop_na = TRUE)
 
   expect_equal(pivot_df$name, c("x", "y"))
   expect_equal(pivot_df$value, c(1,2))
@@ -98,14 +138,14 @@ test_that("can drop missing values", {
 test_that("drops using | condition when using .value", {
   df <- data.table(x_1 = 1, x_2 = 2,  y_1 = NA, y_2 = 2)
   pivot_df <- df %>%
-    pivot_longer.(names_to = c(".value", "id"), names_sep = "_", values_drop_na = TRUE)
+    pivot_longer(names_to = c(".value", "id"), names_sep = "_", values_drop_na = TRUE)
 
   expect_named(pivot_df, c("id", "x", "y"))
   expect_equal(pivot_df$y, c(NA,2))
 
   df <- data.table(x_1 = NA, x_2 = 2,  y_1 = NA, y_2 = 2)
   pivot_df <- df %>%
-    pivot_longer.(names_to = c(".value", "id"), names_sep = "_", values_drop_na = TRUE)
+    pivot_longer(names_to = c(".value", "id"), names_sep = "_", values_drop_na = TRUE)
 
   expect_named(pivot_df, c("id", "x", "y"))
   expect_equal(pivot_df$y, 2)
@@ -113,26 +153,26 @@ test_that("drops using | condition when using .value", {
 
 test_that("... args to melt", {
   df <- data.table(x = c(1, 2), y = c(2,2))
-  expect_named(pivot_longer.(df, c(x,y), verbose = TRUE), c("name", "value"))
+  expect_named(pivot_longer(df, c(x,y), verbose = TRUE), c("name", "value"))
 })
 
 test_that("testing removal of multiple columns", {
   df <- data.table(x = c(1, 2), y = c(2,2), z = c(1,1))
-  expect_named(pivot_longer.(df, c(-x)), c("x", "name", "value"))
-  expect_named(pivot_longer.(df, -x), c("x", "name", "value"))
-  expect_named(pivot_longer.(df, c(-x,-y)), c("x", "y", "name", "value"))
-  expect_error(pivot_longer.(df, c(-x,-y,-z)))
+  expect_named(pivot_longer(df, c(-x)), c("x", "name", "value"))
+  expect_named(pivot_longer(df, -x), c("x", "name", "value"))
+  expect_named(pivot_longer(df, c(-x,-y)), c("x", "y", "name", "value"))
+  expect_error(pivot_longer(df, c(-x,-y,-z)))
 })
 
 test_that("stops if given vector", {
   df <- data.table(x = c(1, 2), y = c(2,2))
-  expect_error(pivot_longer.(df$x, c(x,-y)))
+  expect_error(pivot_longer(df$x, c(x,-y)))
 })
 
 test_that("works with select helpers", {
   df <- data.table(x = 1:2, y = 2, z = 1:2) %>%
-    mutate.(across.(everything(), as.double))
-  pivot_df <- pivot_longer.(df, cols = c(starts_with("y"), contains("z")))[order(name, value)]
+    mutate(across(everything(), as.double))
+  pivot_df <- pivot_longer(df, cols = c(starts_with("y"), contains("z")))[order(name, value)]
 
   expect_named(pivot_df, c("x", "name", "value"))
   expect_equal(pivot_df$x, c(1,2,1,2))
@@ -144,7 +184,7 @@ test_that("names_pattern works", {
   test_df <- data.table(a1_1 = 1, b2_2 = 2)
 
   pivot_df <- test_df %>%
-    pivot_longer.(
+    pivot_longer(
       names_to = c("a", "b"),
       names_pattern = "([[:alnum:]]+)_([[:alnum:]]+)"
     )
@@ -159,7 +199,7 @@ test_that("can pivot all cols (specified) to long with quosure function", {
   df <- data.table(x = 1:2, y = 3:4)
 
   pivot_longer_fn <- function(.df, col1, col2) {
-    pivot_longer.(.df, cols = c({{ col1 }}, {{ col2 }}))
+    pivot_longer(.df, cols = c({{ col1 }}, {{ col2 }}))
   }
 
   pivot_df <- pivot_longer_fn(df, x, y)[order(name, value)]
@@ -171,8 +211,8 @@ test_that("can pivot all cols (specified) to long with quosure function", {
 
 test_that("can use names_prefix", {
   df <- data.table(x_x = 1:2, x_y = 3:4)
-  pivot_df <- pivot_longer.(df, names_prefix = "x_") %>%
-    arrange.(name, value)
+  pivot_df <- pivot_longer(df, names_prefix = "x_") %>%
+    arrange(name, value)
 
   expect_named(pivot_df, c("name", "value"))
   expect_equal(pivot_df$name, c("x","x","y","y"))
@@ -183,7 +223,7 @@ test_that("can pivot to multiple measure cols", {
   test_df <- tidytable(x_3 = 3, x_4 = 4, y_3 = 3, y_4 = 4)
 
   out <- test_df %>%
-    pivot_longer.(names_to = c(".value", "id"), names_sep = "_")
+    pivot_longer(names_to = c(".value", "id"), names_sep = "_")
 
   expect_named(out, c("id", "x", "y"))
   expect_equal(out$id, c("3", "4"))
@@ -193,7 +233,7 @@ test_that("can drop the 'id' column by specifying NA", {
   test_df <- tidytable(x_3 = 3, x_4 = 4, y_3 = 3, y_4 = 4)
 
   out <- test_df %>%
-    pivot_longer.(names_to = c(".value", NA), names_sep = "_")
+    pivot_longer(names_to = c(".value", NA), names_sep = "_")
 
   expect_named(out, c("x", "y"))
   expect_equal(out$x, c(3, 4))
@@ -204,7 +244,7 @@ test_that("balanced data can have different column order", {
   test_df <- tidytable(x_3 = 3, x_4 = 4, y_4 = 4, y_3 = 3)
 
   out <- test_df %>%
-    pivot_longer.(names_to = c(".value", "id"), names_sep = "_")
+    pivot_longer(names_to = c(".value", "id"), names_sep = "_")
 
   expect_named(out, c("id", "x", "y"))
   expect_equal(out$id, c("3", "4"))
@@ -220,16 +260,16 @@ test_that(".value can be at any position in `names_to`", {
   )
 
   value_first <- samp1 %>%
-    pivot_longer.(-i, names_to = c(".value", "time"), names_sep = "_")
+    pivot_longer(-i, names_to = c(".value", "time"), names_sep = "_")
 
   samp2 <- samp1 %>%
-    rename.(t1_y = y_t1,
+    rename(t1_y = y_t1,
             t2_y = y_t2,
             t1_z = z_t1,
             t2_z = z_t2)
 
   value_second <- samp2 %>%
-    pivot_longer.(-i, names_to = c("time", ".value"), names_sep = "_")
+    pivot_longer(-i, names_to = c("time", ".value"), names_sep = "_")
 
   expect_identical(value_first, value_second)
 })
@@ -241,7 +281,7 @@ test_that("works with unbalanced data - 1", {
     x_2 = c(2, 4),
     y_2 = c("a", "b")
   )
-  out <- pivot_longer.(dt, -id, names_to = c(".value", "n"), names_sep = "_")
+  out <- pivot_longer(dt, -id, names_to = c(".value", "n"), names_sep = "_")
 
   expect_named(out, c("id", "n", "x", "y"))
   expect_equal(out$x, c(1, 3, 2, 4))
@@ -251,7 +291,7 @@ test_that("works with unbalanced data - 1", {
 test_that("works with unbalanced data - 2", {
   test_df <- tidytable(x2 = 2, x3 = 3, y5 = 5, y6 = 6)
   out <- test_df %>%
-    pivot_longer.(names_to = c(".value", "id"), names_pattern = "(.)(.)")
+    pivot_longer(names_to = c(".value", "id"), names_pattern = "(.)(.)")
 
   expect_named(out, c("id", "x", "y"))
   expect_equal(out$id, c("2", "3", "5", "6"))
@@ -268,7 +308,7 @@ test_that("works with unbalanced data - 3", {
   )
 
   out <- test_df %>%
-    pivot_longer.(-groups, names_to = c(".value", "labels"), names_sep = "_")
+    pivot_longer(-groups, names_to = c(".value", "labels"), names_sep = "_")
 
   expect_equal(out$groups, rep(1:3, 3))
   expect_equal(out$labels, c(rep("alpha", 3), rep("beta", 3), rep("gamma", 3)))
@@ -287,7 +327,7 @@ test_that("errors with `names_to = '.value'`", {
 
   expect_error(
     dt %>%
-      pivot_longer.(
+      pivot_longer(
         !id,
         names_to = ".value",
         names_pattern = "(.)."
@@ -297,7 +337,7 @@ test_that("errors with `names_to = '.value'`", {
 
 test_that("doesn't convert factor cols to character, #202", {
   fct_df <- tidytable(x = factor("a"), y = factor("b"))
-  out <- pivot_longer.(fct_df)
+  out <- pivot_longer(fct_df)
 
   expect_equal(out$value, as.factor(c("a", "b")))
 })
@@ -314,7 +354,7 @@ test_that("doesn't convert factor cols to character, #234.
   )
 
   out <- df %>%
-    pivot_longer.(names_to = c(".value", "id"), names_sep = "_")
+    pivot_longer(names_to = c(".value", "id"), names_sep = "_")
 
   expect_named(out, c("id", "fct", "dbl", "chr"))
   expect_equal(out$fct, as.factor(c("a", "b")))
