@@ -41,3 +41,10 @@ test_that("multiple before/after works", {
   expect_named(relocate(df, x, .after = c(y, z)), c("y", "z", "x"))
   expect_named(relocate(df, y, .before = c(x, z)), c("y", "x", "z"))
 })
+
+test_that("can rename columns", {
+  df <- data.table(x = 1, y = 2)
+  res <- relocate(df, new_y = y, .before = x)
+  expect_named(res, c("new_y", "x"))
+  expect_equal(res$new_y, 2)
+})
