@@ -3,6 +3,18 @@ test_that("works with no input & works with NA", {
                        b = c("b", "b", "b"),
                        c = c("c", NA, "c"))
 
+  unite_df <- test_df %>%
+    unite()
+
+  expect_named(unite_df, ".united")
+  expect_equal(unite_df$.united, c("a_b_c", "a_b_NA", "a_b_c"))
+})
+
+test_that("unite. works", {
+  test_df <- tidytable(a = c("a", "a", "a"),
+                       b = c("b", "b", "b"),
+                       c = c("c", NA, "c"))
+
   unite_df <- test_df %>%
     unite.()
 
@@ -17,7 +29,7 @@ test_that("works with selected cols", {
                        c = c("c", NA, "c"))
 
   unite_df <- test_df %>%
-    unite.("new_col", a:b)
+    unite("new_col", a:b)
 
   expect_named(unite_df, c("new_col", "c"))
   expect_equal(unite_df$new_col, c("a_b", "a_b", "a_b"))
@@ -25,7 +37,7 @@ test_that("works with selected cols", {
 
 test_that("does not remove new col in case of name clash", {
   df <- data.table(x = "a", y = "b")
-  out <- unite.(df, x, x:y)
+  out <- unite(df, x, x:y)
   expect_equal(names(out), "x")
   expect_equal(out$x, "a_b")
 })
@@ -36,7 +48,7 @@ test_that("na.rm works", {
                        c = c("c", NA, "c"))
 
   unite_df <- test_df %>%
-    unite.("new_col", a:c, na.rm = TRUE)
+    unite("new_col", a:c, na.rm = TRUE)
 
   expect_named(unite_df, "new_col")
   expect_equal(unite_df$new_col, c("a_b_c", "a_b", "a_b_c"))
@@ -48,7 +60,7 @@ test_that("can keep cols", {
                        c = c("c", NA, "c"))
 
   unite_df <- test_df %>%
-    unite.("new_col", a:c, remove = FALSE, na.rm = TRUE)
+    unite("new_col", a:c, remove = FALSE, na.rm = TRUE)
 
   expect_named(unite_df, c("new_col", "a", "b", "c"))
   expect_equal(unite_df$new_col, c("a_b_c", "a_b", "a_b_c"))
@@ -60,7 +72,7 @@ test_that("doesn't modify-by-reference", {
                        c = c("c", NA, "c"))
 
   test_df %>%
-    unite.("new_col", a:b, na.rm = TRUE)
+    unite("new_col", a:b, na.rm = TRUE)
 
   expect_named(test_df, c("a", "b", "c"))
 })
@@ -72,7 +84,7 @@ test_that("works with selected cols with quosure function", {
                        c = c("c", NA, "c"))
 
   unite_fn <- function(.df, col1, col2) {
-    unite.(.df, "new_col", {{ col1 }}, {{ col2 }})
+    unite(.df, "new_col", {{ col1 }}, {{ col2 }})
   }
 
   unite_df <- test_df %>%
